====================
Kenzo Kit for Django
====================

Basic model and views for the simple REST API

Quick start
-----------

Add "kk" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'kk',
    ]
